@@ -30,9 +30,10 @@ my $app = <: $module_name :>->new(
             # SERVER
             server => {    # passed directly to the Pcore::HTTP::Server constructor
                 listen => '/var/run/<: $dist_path :>.sock',
-                ssl    => 0,
             },
 
+            load_balancer => $cfg->{load_balancer},
+
             # ROUTER
             router => {    # passed directly to the Pcore::App::Router
                 '*' => undef,
